View source: R/GetConceptIdDetails.R
| getConceptIdDetails | R Documentation |
given an array of conceptIds, get their details
getConceptIdDetails(
conceptIds,
connection = NULL,
connectionDetails = NULL,
vocabularyDatabaseSchema = "vocabulary",
tempEmulationSchema = getOption("sqlRenderTempEmulationSchema")
)
conceptIds |
An array of Concept ids. |
connection |
An object of type |
connectionDetails |
An object of type |
vocabularyDatabaseSchema |
The schema name of containing the vocabulary tables. |
tempEmulationSchema |
Some database platforms like Oracle and Impala do not truly support temp tables. To emulate temp tables, provide a schema with write privileges where temp tables can be created. |
Returns a tibble data frame.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.