View source: R/GetCountOfSourceCodesMappedToStandardConcept.R
| getCountOfSourceCodesMappedToStandardConcept | R Documentation |
Given conceptId(s) get the counts of occurrence with mapping.
getCountOfSourceCodesMappedToStandardConcept(
conceptIds,
connection = NULL,
connectionDetails = NULL,
cdmDatabaseSchema,
tempEmulationSchema = getOption("sqlRenderTempEmulationSchema"),
minCellCount = 0
)
conceptIds |
An array of Concept ids. |
connection |
An object of type |
connectionDetails |
An object of type |
cdmDatabaseSchema |
Schema name where your patient-level data in OMOP CDM format resides. Note that for SQL Server, this should include both the database and schema name, for example 'cdm_data.dbo'. |
tempEmulationSchema |
Some database platforms like Oracle and Impala do not truly support temp tables. To emulate temp tables, provide a schema with write privileges where temp tables can be created. |
minCellCount |
The minimum cell count for fields containing person/subject count. |
Returns a tibble data frame.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.