View source: R/GetExcludedConceptIdsInConceptSetExpression.R
| getExcludedConceptsInConceptSetExpression | R Documentation |
Given a concept set expression, get the resolved concepts
getExcludedConceptsInConceptSetExpression(
conceptSetExpression,
connection = NULL,
connectionDetails = NULL,
tempEmulationSchema = getOption("sqlRenderTempEmulationSchema"),
vocabularyDatabaseSchema = "vocabulary"
)
conceptSetExpression |
An R-object (list) with expression of the concept set. |
connection |
An object of type |
connectionDetails |
An object of type |
tempEmulationSchema |
Some database platforms like Oracle and Impala do not truly support temp tables. To emulate temp tables, provide a schema with write privileges where temp tables can be created. |
vocabularyDatabaseSchema |
The schema name of containing the vocabulary tables. |
Returns a tibble data frame.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.