View source: R/GetRecommendationStandard.R
| getRecommendedStandard | R Documentation |
given a list of standard conceptIds, get recommended concepts.
getRecommendedStandard(
conceptIds,
vocabularyDatabaseSchema,
connection = NULL,
connectionDetails = NULL,
conceptPrevalenceSchema = "concept_prevalence",
tempEmulationSchema = getOption("sqlRenderTempEmulationSchema")
)
conceptIds |
An array of Concept ids. |
vocabularyDatabaseSchema |
The schema name of containing the vocabulary tables. |
connection |
An object of type |
connectionDetails |
An object of type |
conceptPrevalenceSchema |
The schema name that has the concept prevalence table. The following tables are expected to be present. recommender_set, cp_master, recommended_blacklist. |
tempEmulationSchema |
Some database platforms like Oracle and Impala do not truly support temp tables. To emulate temp tables, provide a schema with write privileges where temp tables can be created. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.