View source: R/MapMedraToSnomedViaVocabulary.R
| mapMedraToSnomedViaVocabulary | R Documentation |
given an array of conceptIds belonging to MedDRA vocabulary get its equivalent SNOMED ranked using a combination of OMOP vocabulary mapping, lexical string matching and concept prevalence counts
mapMedraToSnomedViaVocabulary(
conceptIds,
connection = NULL,
connectionDetails = NULL,
tempEmulationSchema = getOption("sqlRenderTempEmulationSchema"),
vocabularyDatabaseSchema = "vocabulary"
)
conceptIds |
An array of Concept ids. |
connection |
An object of type |
connectionDetails |
An object of type |
tempEmulationSchema |
Some database platforms like Oracle and Impala do not truly support temp tables. To emulate temp tables, provide a schema with write privileges where temp tables can be created. |
vocabularyDatabaseSchema |
The schema name of containing the vocabulary tables. |
Returns a tibble data frame
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.