View source: R/PerformStringSearchForConcepts.R
| performStringSearchForConcepts | R Documentation |
Get concepts that match a string search
performStringSearchForConcepts(
searchPhrases,
vocabularyDatabaseSchema = "vocabulary",
connection = NULL,
connectionDetails = NULL,
vocabularyIdOfInterest = c("SNOMED", "HCPCS", "ICD10CM", "ICD10", "ICD9CM", "ICD9",
"Read"),
domainIdOfInterest = c("Condition", "Procedure", "Observation"),
retrieveInvalidConcepts = FALSE
)
searchPhrases |
An array of phrases (each phrase may be multiple words, but each phrase should be quoted and comma separated) to search for. Phrases that have a character length of <4 are not searched. |
vocabularyDatabaseSchema |
The schema name of containing the vocabulary tables. |
connection |
An object of type |
connectionDetails |
An object of type |
vocabularyIdOfInterest |
A list of vocabulary ids to filter the results. |
domainIdOfInterest |
A list of domain ids to filter the results. |
retrieveInvalidConcepts |
Do you want to retrieve invalid concepts. Default = FALSE |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.